@@ -1,5 +1,5 @@
-package Search::Elasticsearch::Client::1_0::Async::Scroll;
-$Search::Elasticsearch::Client::1_0::Async::Scroll::VERSION = '5.01';
+package Search::Elasticsearch::Client::2_0::Async::Scroll;
+$Search::Elasticsearch::Client::2_0::Async::Scroll::VERSION = '6.80';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Search::Elasticsearch::Async::Util qw(thenable);
@@ -14,7 +14,7 @@ has 'on_error'      => ( is => 'lazy', clearer => '_clear_on_error' );
 has '_guard'        => ( is => 'rwp', clearer => '_clear__guard' );
 
 with 'Search::Elasticsearch::Role::Is_Async',
-    'Search::Elasticsearch::Client::1_0::Role::Scroll';
+    'Search::Elasticsearch::Client::2_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -215,11 +215,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Async::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::2_0::Async::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 5.01
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -267,20 +267,20 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::1_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::2_0::Direct/scroll()> methods to make
 them easier to use.
 
 B<IMPORTANT>: Deep scrolling can be expensive.  See L</DEEP SCROLLING>
 for more.
 
-This class does L<Search::Elasticsearch::Client::1_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::2_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 USE CASES
@@ -360,7 +360,7 @@ C<client_id>:
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
 marry a scrolled search with bulk indexing is to use the
-L<Search::Elasticsearch::Client::1_0::Async::Bulk/reindex()> method.
+L<Search::Elasticsearch::Client::2_0::Async::Bulk/reindex()> method.
 
 =head1 DEEP SCROLLING
 
@@ -416,14 +416,14 @@ are memory constrained, you will need to take this into account.
     );
     $scroll->start;
 
-The L<Search::Elasticsearch::Client::1_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::1_0::Async::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::2_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::2_0::Async::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">),
 C<scroll_in_qs> (which defaults to C<false>), and any
 of the listed callbacks. Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::1_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::2_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -432,7 +432,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::1_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::2_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -561,21 +561,21 @@ This value can only be checked once the scroll has completed.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::1_0::Async::Bulk/reindex()>
+=item * L<Search::Elasticsearch::Client::2_0::Async::Bulk/reindex()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/scroll()>
 
 =back
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
